==> photo-translation-xiaomi-2.1.4-sources.jar: com/talpa/translate/activity/CameraActivity.kt <==
package com.talpa.translate.activity

import android.Manifest
import android.app.Activity
import android.content.*
import android.content.pm.PackageManager.PERMISSION_GRANTED
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.provider.MediaStore
import android.text.TextUtils
import android.util.Log
import android.view.KeyEvent
import android.view.View
import androidx.annotation.RestrictTo
import androidx.appcompat.app.AppCompatActivity
import androidx.core.app.ActivityCompat
import androidx.core.content.ContextCompat
import androidx.core.content.FileProvider
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.photo.translation.R
import com.talpa.TranslationController
import com.talpa.translate.base.utils.*
import com.talpa.translate.camera.CameraFragment
import com.talpa.translate.dialog.DiskAlertDialog
import java.io.File


private val PERMISSIONS_REQUIRED = arrayOf(
    Manifest.permission.CAMERA,
    Manifest.permission.WRITE_EXTERNAL_STORAGE,
    Manifest.permission.READ_EXTERNAL_STORAGE
)

private const val REQUEST_CODE_PERMISSIONS = 100
const val ACTION_FOR_NOTIFICATION_CAMERA = "com.talpa.translate.CAMERA_PENDING"
/**
 * Camera Preview
 *
 * @author CY 2020-02-03
 */
class CameraActivity : AppCompatActivity(), DiskAlertDialog.Callback {

    @RestrictTo(RestrictTo.Scope.LIBRARY)
    companion object {

        fun start(context: Activity, requestCode: Int) {
            val intent = Intent(context, CameraActivity::class.java)
            context.startActivityForResult(intent, requestCode)
        }

        fun start(context: Context, requestCode: Int, screenShotPath: String, id: Long) {
            val intent = Intent(context, CameraActivity::class.java)
            intent.putExtra(TranslationController.SCREENSHOT_PATH, screenShotPath)
            intent.putExtra(TranslationController.SCREENSHOT_ID, id)
            intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
            context.startActivity(intent)
        }

    }

    override fun onCreate(savedInstanceState: Bundle?) {
        /*window.decorView.systemUiVisibility = View.SYSTEM_UI_FLAG_HIDE_NAVIGATION or
                View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY or
                View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN or
                View.SYSTEM_UI_FLAG_FULLSCREEN or
                View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION or
                View.SYSTEM_UI_FLAG_LAYOUT_STABLE*/

        super.onCreate(savedInstanceState)

        if (!checkPermission(this)) {
            ActivityCompat.requestPermissions(
                this,
                PERMISSIONS_REQUIRED,
                REQUEST_CODE_PERMISSIONS
            )
            return
        } else {
            setContentView(R.layout.activity_camerax)
            dealIntent()
            if (!checkEnv()) {
                showNoticeDialog()
                return
            }
        }
        handleIntent()
    }

    private fun checkEnv() : Boolean {
        return getFreeSpace() >= 30 * 1024
    }

    private fun handleIntent() {
        if (intent.action.equals(ACTION_FOR_NOTIFICATION_CAMERA)) {
            logEvent(NT_notification_click, "opt", "3")
        }
    }

    override fun onLackUsageConfirm() {
        finish()
    }

    private fun showNoticeDialog() {
        // Create an instance of the dialog fragment and show it
        val dialog = DiskAlertDialog()
            .also {
                it.isCancelable = false
            }
        dialog.show(supportFragmentManager, "DiskAlertDialog")
    }

    private fun dealIntent() {

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
            val screenshotId = intent.getLongExtra(TranslationController.SCREENSHOT_ID, -1L)
            if (screenshotId != -1L) {
                Log.d("cjslog", "screen shot:${screenshotId}")
                val f = supportFragmentManager.findFragmentById(R.id.container) as? CameraFragment
                if (f != null) {
                    val uri: Uri = ContentUris.withAppendedId(
                        MediaStore.Images.Media.EXTERNAL_CONTENT_URI,
                        screenshotId.toLong()
                    )

                    f.setScreenShotMode(true)
                    f.setImageFromShot(uri)
                }
            }
        } else {
            val screenshot = intent.getStringExtra(TranslationController.SCREENSHOT_PATH)
            if (!TextUtils.isEmpty(screenshot)) {
                Log.d("cjslog", "screen shot:${screenshot}")
                val f = supportFragmentManager.findFragmentById(R.id.container) as? CameraFragment
                if (f != null) {
                    val uri: Uri
                    val file = File(screenshot)
                    Log.d("cjslog", "file exsist:${file.exists()}")
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
                        uri =
                            FileProvider.getUriForFile(
                                this,
                                packageName + ".fileProvider",
                                file
                            )
                    } else {
                        uri = Uri.fromFile(file)
                    }

                    f.setScreenShotMode(true)
                    f.setImageFromShot(uri)
                }
            }
        }


    }

    private fun checkPermission(context: Context): Boolean {
        return PERMISSIONS_REQUIRED.all {
            PERMISSION_GRANTED == ContextCompat.checkSelfPermission(context, it)
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int,
        permissions: Array<out String>,
        grantResults: IntArray
    ) {

        when (requestCode) {
            REQUEST_CODE_PERMISSIONS -> {
                //&& !supportFragmentManager.isStateSaved
                if (checkPermission(applicationContext)) {
                    //TranslationStateEngine.post(TranslationSessionFactory.buildDefaultSession())
                    setContentView(R.layout.activity_camerax)
                    dealIntent()
                } else {
                    finish()
                }
            }
        }

        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
    }

    /*override fun onKeyDown(keyCode: Int, event: KeyEvent?): Boolean {

        return when (keyCode) {
            KeyEvent.KEYCODE_BACK -> {
                val intent = Intent(KEY_EVENT_ACTION).apply {
                    putExtra(
                        KEY_EVENT_EXTRA, keyCode
                    )
                }
                LocalBroadcastManager.getInstance(applicationContext).sendBroadcast(intent)
                true
            }
            else -> super.onKeyDown(keyCode, event)
        }
    }*/

}

==> photo-translation-xiaomi-2.2.88-sources.jar: com/talpa/translate/activity/CameraActivity.kt <==
package com.talpa.translate.activity

import android.Manifest
import android.app.Activity
import android.content.*
import android.content.pm.PackageManager.PERMISSION_GRANTED
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.provider.MediaStore
import android.text.TextUtils
import androidx.annotation.RestrictTo
import androidx.appcompat.app.AppCompatActivity
import androidx.core.app.ActivityCompat
import androidx.core.content.ContextCompat
import androidx.core.content.FileProvider
import com.photo.translation.R
import com.talpa.PhotoTranslateController
import com.talpa.translate.base.utils.*
import com.talpa.translate.camera.CameraFragment
import com.talpa.translate.dialog.DiskAlertDialog
import java.io.File

private val PERMISSIONS_REQUIRED = arrayOf(
    Manifest.permission.CAMERA,
    Manifest.permission.WRITE_EXTERNAL_STORAGE,
    Manifest.permission.READ_EXTERNAL_STORAGE
)

private const val REQUEST_CODE_PERMISSIONS = 100
const val ACTION_FOR_NOTIFICATION_CAMERA = "com.talpa.translate.CAMERA_PENDING"
/**
 * Camera Preview
 *
 * @author CY 2020-02-03
 */
class CameraActivity : AppCompatActivity(), DiskAlertDialog.Callback {

    @RestrictTo(RestrictTo.Scope.LIBRARY)
    companion object {

        fun start(context: Activity, requestCode: Int) {
            val intent = Intent(context, CameraActivity::class.java)
            context.startActivityForResult(intent, requestCode)
        }

        fun start(context: Context, requestCode: Int, screenShotPath: String, id: Long) {
            val intent = Intent(context, CameraActivity::class.java)
            intent.putExtra(PhotoTranslateController.SCREENSHOT_PATH, screenShotPath)
            intent.putExtra(PhotoTranslateController.SCREENSHOT_ID, id)
            intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
            context.startActivity(intent)
        }

    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        if (!checkPermission(this)) {
            ActivityCompat.requestPermissions(
                this,
                PERMISSIONS_REQUIRED,
                REQUEST_CODE_PERMISSIONS
            )
            return
        } else {
            setContentView(R.layout.activity_camerax)
            dealIntent()
            if (!checkEnv()) {
                showNoticeDialog()
                return
            }
        }
        handleIntent()
    }

    private fun checkEnv() : Boolean {
        return getFreeSpace() >= 30 * 1024
    }

    private fun handleIntent() {
        if (intent.action.equals(ACTION_FOR_NOTIFICATION_CAMERA)) {
            logEvent(NT_notification_click, "opt", "3")
        }
    }

    override fun onLackUsageConfirm() {
        finish()
    }

    private fun showNoticeDialog() {
        // Create an instance of the dialog fragment and show it
        val dialog = DiskAlertDialog()
            .also {
                it.isCancelable = false
            }
        dialog.show(supportFragmentManager, "DiskAlertDialog")
    }

    private fun dealIntent() {

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
            val screenshotId = intent.getLongExtra(PhotoTranslateController.SCREENSHOT_ID, -1L)
            if (screenshotId != -1L) {
                val f = supportFragmentManager.findFragmentById(R.id.container) as? CameraFragment
                if (f != null) {
                    val uri: Uri = ContentUris.withAppendedId(
                        MediaStore.Images.Media.EXTERNAL_CONTENT_URI,
                        screenshotId.toLong()
                    )

                    f.setScreenShotMode(true)
                    f.setImageFromShot(uri)
                }
            }
        } else {
            val screenshot = intent.getStringExtra(PhotoTranslateController.SCREENSHOT_PATH)
            if (!TextUtils.isEmpty(screenshot)) {
                val f = supportFragmentManager.findFragmentById(R.id.container) as? CameraFragment
                if (f != null) {
                    val uri: Uri
                    val file = File(screenshot ?: return)
                    if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
                        uri =
                            FileProvider.getUriForFile(
                                this,
                                packageName + ".fileProvider",
                                file
                            )
                    } else {
                        uri = Uri.fromFile(file)
                    }

                    f.setScreenShotMode(true)
                    f.setImageFromShot(uri)
                }
            }
        }


    }

    private fun checkPermission(context: Context): Boolean {
        return PERMISSIONS_REQUIRED.all {
            PERMISSION_GRANTED == ContextCompat.checkSelfPermission(context, it)
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int,
        permissions: Array<out String>,
        grantResults: IntArray
    ) {

        when (requestCode) {
            REQUEST_CODE_PERMISSIONS -> {
                //&& !supportFragmentManager.isStateSaved
                if (checkPermission(applicationContext)) {
                    //TranslationStateEngine.post(TranslationSessionFactory.buildDefaultSession())
                    setContentView(R.layout.activity_camerax)
                    dealIntent()
                } else {
                    finish()
                }
            }
        }

        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
    }

}
